==> haskell-lua-arbitrary-1.0.1.1-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lua-arbitrary
version:              1.0.1.1
visibility:           public
id:                   lua-arbitrary-1.0.1.1-5HBNz419DQ6G7J2Lw4fMyW
key:                  lua-arbitrary-1.0.1.1-5HBNz419DQ6G7J2Lw4fMyW
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  1ffbca36a459c3342404ab037fb74a03
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.2.8/site-local/lua-arbitrary-1.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lua-arbitrary-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lua-arbitrary
hs-libraries:         HSlua-arbitrary-1.0.1.1-5HBNz419DQ6G7J2Lw4fMyW
depends:
    QuickCheck-2.14.3-ETIaN96hws5IxTx9oCxxHN base-4.16.4.0
    lua-2.3.3-EDa4xxl8xsiFVlSKgLZzK1

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lua-arbitrary-1.0.1.1-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lua-arbitrary
version:              1.0.1.1
visibility:           public
id:                   lua-arbitrary-1.0.1.1-6MTKRHCONEWCAgMPWGXAHe
key:                  lua-arbitrary-1.0.1.1-6MTKRHCONEWCAgMPWGXAHe
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  3436c6a6eaaf3facf7f43d2b5f7f8261
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.2.8/site-local/lua-arbitrary-1.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lua-arbitrary-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lua-arbitrary
hs-libraries:         HSlua-arbitrary-1.0.1.1-6MTKRHCONEWCAgMPWGXAHe
depends:
    QuickCheck-2.14.3-7UtqTMZe3jxBonzxyjYW4P base-4.16.4.0
    lua-2.3.3-7B47Na1ItnE3sioih3rGLS

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
